@@ -25,26 +25,22 @@
 "btgp" <-
 function(X, Z, XX=NULL, bprior="bflat", corr="expsep", tree=c(0.25,2,10), 
 	BTE=c(2000,7000,2), R=1, m0r1=FALSE, linburn=FALSE, pred.n=TRUE,
-        ds2x=FALSE, ego=FALSE, nu=0.5, traces=FALSE, verb=1)##,
-	##base="gp", mrd.p =c(1,100,1,20), delta.p=c(2,2,2,2), nugf.p=c(1,20,1,1))
+        ds2x=FALSE, ego=FALSE, nu=1.5, traces=FALSE, verb=1)##, 
+	##base="gp"))
 {
   n <- dim(X)[1]
   if(is.null(n)) { n <- length(X); X <- matrix(X, nrow=n); d <- 1 }
   else { d <- dim(X)[2] }
   
-  ##params <- tgp.default.params(d+1, base=base)
-  params <- tgp.default.params(d+1)
+  params <- tgp.default.params(d+1)##, base=base)
 
   params$bprior <- bprior
   params$corr <- corr
   params$tree <- tree;
   params$gamma <- c(0,0.2,0.7)	# no llm
-  ##if(base == "mrgp"){ 
-	##params$d.p <- c(params$d.p, mrd.p)
-	##params$delta.p <- delta.p
-	##params$nugf.p <- nugf.p
-  ##}
-  if(corr == "matern") params$nu<-nu 
+  
+  if(corr == "matern") params$nu<-nu
+  
   return(tgp(X,Z,XX,BTE,R,m0r1,linburn,params,pred.n,ds2x,ego,traces,verb))
 }
 
