@@ -24,7 +24,7 @@
 
 "btlm" <-
 function(X, Z, XX=NULL, bprior="bflat", tree=c(0.25,2,10), BTE=c(2000,7000,2), 
-	R=1, m0r1=FALSE, pred.n=TRUE, ds2x=FALSE, ego=FALSE, verb=1)
+	R=1, m0r1=FALSE, pred.n=TRUE, ds2x=FALSE, ego=FALSE, traces=FALSE, verb=1)
 {
   n <- dim(X)[1]
   if(is.null(n)) { n <- length(X); X <- matrix(X, nrow=n); d <- 1 }
@@ -33,6 +33,6 @@ function(X, Z, XX=NULL, bprior="bflat", tree=c(0.25,2,10), BTE=c(2000,7000,2),
   params$bprior <- bprior
   params$tree <- tree
   params$gamma <- c(-1,0.2,0.7)	# no llm
-  return(tgp(X,Z,XX,BTE,R,m0r1,FALSE,params,pred.n,ds2x,ego,verb))
+  return(tgp(X,Z,XX,BTE,R,m0r1,FALSE,params,pred.n,ds2x,ego,traces,verb))
 }
 
