@@ -23,42 +23,44 @@
 
 
 "tgp.cleanup" <-
-  function()
+  function(verb)
 {
   .C("tgp_cleanup", PACKAGE = "tgp")
   
   if(file.exists(paste("./", "best_parts_1.out", sep=""))) {
-    cat("INTERRUPT: removed best_parts_1.out\n")
+    if(verb >= 1) cat("INTERRUPT: removed best_parts_1.out\n")
     unlink("best_parts_1.out")
   } 
   
   if(file.exists(paste("./", "tree_m0_posts.out", sep=""))) {
-    cat("INTERRUPT: removed tree_m0_posts.out\n")
+    if(verb >= 1) cat("INTERRUPT: removed tree_m0_posts.out\n")
     unlink("tree_m0_posts.out")
   }
 
   if(file.exists(paste("./", "trace_parts_1.out", sep=""))) {
-    cat("INTERRUPT: removed trace_parts_1.out\n")
+    if(verb >= 1) cat("INTERRUPT: removed trace_parts_1.out\n")
     unlink("trace_parts_1.out")
   } 
 
   if(file.exists(paste("./", "trace_post_1.out", sep=""))) {
-    cat("INTERRUPT: removed trace_post_1.out\n")
+    if(verb >= 1) cat("INTERRUPT: removed trace_post_1.out\n")
     unlink("trace_post_1.out")
   } 
 
   if(file.exists(paste("./", "trace_linarea_1.out", sep=""))) {
-    cat("INTERRUPT: removed trace_linarea_1.out\n")
+    if(verb >= 1) cat("INTERRUPT: removed trace_linarea_1.out\n")
     unlink("trace_linarea_1.out")
   } 
 
   if(file.exists(paste("./", "trace_XX_1.out", sep=""))) {
-    cat("INTERRUPT: removed trace_XX_1.out\n")
+    if(verb >= 1) cat("INTERRUPT: removed trace_XX_1.out\n")
     unlink("trace_XX_1.out")
   } 
 
   if(file.exists(paste("./", "trace_ZZ_1.out", sep=""))) {
-    cat("INTERRUPT: removed trace_ZZ_1.out\n")
+    if(verb > 1) cat("INTERRUPT: removed trace_ZZ_1.out\n")
     unlink("trace_ZZ_1.out")
-  } 
+  }
+
+  if(verb >= 1) cat("\n")
  }
